@@ -9,10 +9,12 @@ and as measures of error generally.
 
 import logging
 from typing import List
-import numpy as np
+
 import cv2
-import sksurgeryopencvpython as cvpy
+import numpy as np
 import sksurgerycore.transforms.matrix as mu
+
+import sksurgerycalibration.algorithms.triangulate as at
 import sksurgerycalibration.video.video_calibration_utils as vu
 
 LOGGER = logging.getLogger(__name__)
@@ -149,19 +151,6 @@ def compute_stereo_3d_error(l2r_rmat,
                                 right_camera_matrix,
                                 right_distortion, None, right_camera_matrix)
 
-        # Triangulate using OpenCV
-#        l2r_mat = mu.construct_rigid_transformation(l2r_rmat, l2r_tvec)
-#        p_l = np.zeros((3, 4))
-#        p_l[:, :-1] = left_camera_matrix
-#        p_r = np.zeros((3, 4))
-#        p_r[:, :-1] = right_camera_matrix
-#        p_l = np.matmul(p_l, np.eye(4))
-#        p_r = np.matmul(p_r, l2r_mat)
-#        triangulated_cv = cv2.triangulatePoints(p_l,
-#                                                p_r,
-#                                                left_undistorted,
-#                                                right_undistorted)
-
         # convert from Mx1x2 to Mx2
         left_undistorted = np.reshape(left_undistorted, (-1, 2))
         right_undistorted = np.reshape(right_undistorted, (-1, 2))
@@ -170,8 +159,7 @@ def compute_stereo_3d_error(l2r_rmat,
         image_points[:, 0:2] = left_undistorted
         image_points[:, 2:4] = right_undistorted
 
-        #pylint:disable=c-extension-no-member
-        triangulated = cvpy.triangulate_points_using_hartley(
+        triangulated = at.triangulate_points_hartley(
             image_points,
             left_camera_matrix,
             right_camera_matrix,
