@@ -10,23 +10,8 @@ import pytest
 import numpy as np
 import sksurgeryimage.calibration.chessboard_point_detector as pd
 import sksurgeryimage.calibration.charuco_plus_chessboard_point_detector as chpd
-import sksurgerycalibration.video as vidcal
-
-
-def test_set_model2hand_arrays():
-    """Test that model2hand arrays are set without raising an error"""
-    chessboard_detector = pd.ChessboardPointDetector((14, 10), 3, (1, 1))
-
-    stereo_calib = \
-        vidcal.video_calibration_driver_stereo.StereoVideoCalibrationDriver(
-            chessboard_detector, chessboard_detector, 140)
-
-    tracking_data_dir = 'tests/data/2020_01_20_storz/12_50_30'
-    file_prefix = 'calib'
-
-    stereo_calib.load_data(tracking_data_dir, file_prefix)
-
-    stereo_calib.tracking_data.set_model2hand_arrays()
+import sksurgerycalibration.video.video_calibration_driver_mono as mcd
+import sksurgerycalibration.video.video_calibration_driver_stereo as scd
 
 
 def load_images_from_glob(glob_pattern):
@@ -81,31 +66,26 @@ def test_handeye_calibration_mono():
                                                 error_if_no_chessboard=False)
 
     calibrator = \
-        vidcal.video_calibration_driver_mono.MonoVideoCalibrationDriver(
-            detector, min_number_of_points_per_image)
+        mcd.MonoVideoCalibrationDriver(detector, min_number_of_points_per_image)
 
     # Grab data from images/tracking arrays
     for image, device, calib_obj in zip(images, device_tracking, obj_tracking):
         successful = calibrator.grab_data(image, device, calib_obj)
         assert successful > 0
 
-    reproj_err_1, recon_err_1, _ = calibrator.calibrate()
+    reproj_err_1, _ = calibrator.calibrate()
 
     assert reproj_err_1 == pytest.approx(1., rel=0.2)
-    assert recon_err_1 == pytest.approx(0.26, rel=0.2)
 
-    proj_err, recon_err, _ = calibrator.handeye_calibration()
+    proj_err, _ = calibrator.handeye_calibration()
 
     print(f'Reproj err {proj_err}')
-    print(f'Recon err {recon_err}')
 
     # These values are taken from a previous successful run
     # Not objective measures of correctness
-    expected_reproj_error = 14.97731
-    expected_recon_error = 5.434362
+    expected_reproj_error = 10.412839
 
     assert proj_err == pytest.approx(expected_reproj_error, rel=0.1)
-    assert recon_err == pytest.approx(expected_recon_error, rel=0.1)
 
 
 def test_handeye_calibration_stereo():
@@ -140,7 +120,7 @@ def test_handeye_calibration_stereo():
                                                 error_if_no_chessboard=False)
 
     calibrator = \
-        vidcal.video_calibration_driver_stereo.StereoVideoCalibrationDriver(
+        scd.StereoVideoCalibrationDriver(
             detector, detector, min_number_of_points_per_image)
 
     # Grab data from images/tracking arrays
@@ -160,20 +140,14 @@ def test_handeye_calibration_stereo():
     assert reproj_err_1 == pytest.approx(0.6, rel=0.2)
     assert recon_err_1 == pytest.approx(1., rel=0.2)
 
-    proj_err, recon_err, _ = calibrator.handeye_calibration()
+    proj_err, recon_err, _ = \
+        calibrator.handeye_calibration(use_opencv=True, do_bundle_adjust=True)
 
     print(f'Reproj err {proj_err}')
     print(f'Recon err {recon_err}')
 
-    # These values are taken from a previous successful run
-    # Not objective measures of correctness
-    # expected_reproj_error = 1.77138
-    # expected_recon_error = 1.24267
-    # Unfortunately the tolerances need to change depending on OS and
-    # software versions. py3.7 on ubuntu returned 2.94
-
-    assert proj_err == pytest.approx(1.8, rel=1.7)
-    assert recon_err == pytest.approx(1.2, rel=0.2)
+    assert proj_err == pytest.approx(7.3, rel=1.7)
+    assert recon_err == pytest.approx(2.5, rel=0.3)
 
     # test save/load for hand-eye
     calibrator.save_params('tests/output/test_handeye_calibration_stereo', '')
@@ -197,7 +171,7 @@ def test_load_data_stereo_calib():
     chessboard_detector = pd.ChessboardPointDetector((14, 10), 3, (1, 1))
 
     stereo_calib = \
-        vidcal.video_calibration_driver_stereo.StereoVideoCalibrationDriver(
+        scd.StereoVideoCalibrationDriver(
             chessboard_detector, chessboard_detector, 140)
 
     tracking_data_dir = 'tests/data/2020_01_20_storz/12_50_30'
